#!/bin/sh


#echo "Running $0" 1>&2

PATH="${HOME}/bin/`uname`:${HOME}/bin:${PATH}:/usr/bin:/bin"

  #### Utility

exitOnErr()
{ estat="$1"
  emsg="$2"
  if [ x"$estat" != x"0" ] ; then
    echo "$emsg" 1>&2
    exit $estat
  fi
}

  #### Default TMPDIR

if [ x"$TMPDIR" = x"" ] ; then
  TMPDIR="${HOME}/tmp"
  export TMPDIR
fi

  #### working directory

work="${TMPDIR}/extractContained.$$"
mkdir -p "$work"
exitOnErr $? "Can't mkdir -p ${work}"

cd ${work}
exitOnErr $? "Can't cd ${work}"

  #### get input

cat > input.mail
exitOnErr $? "cp input to temp failed"

  #### extract the contained message

mkdir output
exitOnErr $? "Can't mkdir ${work}/output"

tmpOut=munpack-output.$$.mail
tmpDesc=munpack-output.$$.desc
munpack -C output -m ${tmpOut} ../input.mail >munpack.out 2>&1
exitOnErr $? "munpack failed"

  #### check extracted messages

if [ ! -s "output/$tmpOut" ] ; then
  exitOnErr 1 "missing output/${tmpOut}"
fi
if [ -s "output/${tmpDesc}" ] ; then
    # HOOK: Maybe some content is sometimes OK?
  exitOnErr 1 "non-zero description"
fi

  #### compose output

( head -1 input.mail  # For "From " (no colon) line.
  cat output/"$tmpOut"
) > output.mail

  #### verify that nothing else was extracted

rm -f "output/$tmpOut" "output/${tmpDesc}"

rmdir output
exitOnErr $? "can't remove output normally"

  #### write output

cat output.mail
exitOnErr $? "can't cat output"

  #### cleanup

cd ..
rm -rf ${work}

exit 0
